@@ -2,12 +2,13 @@ package Shell::Config::Generate;
 
 use strict;
 use warnings;
+use 5.008001;
 use Shell::Guess;
 use Carp qw( croak );
 use Exporter ();
 
 # ABSTRACT: Portably generate config for any shell
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 
 sub new
@@ -359,10 +360,10 @@ sub generate
 sub generate_file
 {
   my($self, $shell, $filename) = @_;
-  use autodie;
-  open my $fh, '>', $filename;
-  print $fh $self->generate($shell);
-  close $fh;
+  my $fh;
+  open($fh, '>', $filename) or die "cannot open $filename: $!";
+  print $fh $self->generate($shell) or die "cannot write $filename: $!";
+  close $fh or die "error closing $filename: $!";
 }
 
 *import = \&Exporter::import;
@@ -393,7 +394,7 @@ Shell::Config::Generate - Portably generate config for any shell
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
@@ -729,8 +730,6 @@ newer versions.
 
 Patches welcome for your favorite shell / operating system.
 
-=cut
-
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
